@@ -1,4 +1,5 @@
-from c_saxssim import *
+from c_saxssim import theorsaxs2D,Ctheorsphere2D,Ctheorspheregas,Ctheorspheres,maxdistance,unidir,grf_saxs2D,grf_realize,ddistcylinder,ddistsphere,ddistellipsoid,ddistbrick,ftddist,ddistgrf,charfuncgrf
+import numpy as np
 
 def grf_savevtk(file,grfmatrix,origin=None,spacing=None):
     if type(file)==type(''):
